@@ -143,14 +143,17 @@ def jsonifyIt(object, fieldsToExpand=[EXPAND_ALL_FIELDS]) :
 def instanciateItWithNoArgsConstructor(objectClass) :
     args = []
     objectInstance = None
-    for ammountOfVariables in range(60) :
-        try :
-            objectInstance = objectClass(*args)
-            break
-        except :
-            args.append(None)
+    try :
+        objectInstance = objectClass()
+    except :
+        for ammountOfVariables in range(60) :
+            try :
+                objectInstance = objectClass(*args)
+                break
+            except :
+                args.append(None)
     if not objectInstance :
-        raise Exception(f'Not possible to instanciate {objectClass} class in instanciateItWithNoArgsConstructor() method')
+        raise Exception(f'Not possible to instanciate {objectClass} class in instanciateItWithNoArgsConstructor() method with None as args constructor')
     return objectInstance
 
 @Function
